@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.110 2008/06/09 17:24:17 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.113 2008/07/11 16:49:53 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -1093,7 +1093,8 @@ static int udp_listener(const char *ssm_source,
 			int ssm_source_addrlen,
 			const char *hostname,
 			const char *portname, 
-			int mcast_join)
+			int mcast_join,
+			const char *join_iface)
 {
   struct addrinfo hints;
   struct addrinfo *ai_res;
@@ -1163,21 +1164,25 @@ static int udp_listener(const char *ssm_source,
 			     0 /* tcp nodelay */,
 			     nepim_global.tos,
 			     nepim_global.server_tcp_mss,
-			     0 /* "any" interface index */,
+			     join_iface,
 			     ssm_source_addr,
 			     ssm_source_addrlen);
     if (sd < 0) {
       if (ssm_source)
 	fprintf(stderr, 
-		"%s %s: UDP listener socket failed for %s+%s,%d: %d\n",
+		"%s %s: UDP listener socket failed for %s+%s@%s,%d: %d\n",
 		__FILE__, __PRETTY_FUNCTION__,
 		ssm_source_addrstr,
-		addr_str, nepim_sock_get_port(ai->ai_addr), sd);
+		addr_str,
+		join_iface ? join_iface : "any",
+		nepim_sock_get_port(ai->ai_addr), sd);
       else
 	fprintf(stderr, 
-		"%s %s: UDP listener socket failed for %s,%d: %d\n",
+		"%s %s: UDP listener socket failed for %s@%s,%d: %d\n",
 		__FILE__, __PRETTY_FUNCTION__,
-		addr_str, nepim_sock_get_port(ai->ai_addr), sd);
+		addr_str,
+		join_iface ? join_iface : "any",
+		nepim_sock_get_port(ai->ai_addr), sd);
       continue;
     }
 
@@ -1191,13 +1196,17 @@ static int udp_listener(const char *ssm_source,
 
     if (ssm_source)
 	fprintf(stderr, 
-		"%d: UDP socket listening on %s+%s,%d\n",
+		"%d: UDP socket listening on %s+%s@%s,%d\n",
 		sd, ssm_source_addrstr,
-		addr_str, nepim_sock_get_port(ai->ai_addr));
+		addr_str,
+		join_iface ? join_iface : "any",
+		nepim_sock_get_port(ai->ai_addr));
       else
 	fprintf(stderr, 
-		"%d: UDP socket listening on %s,%d\n",
-		sd, addr_str, nepim_sock_get_port(ai->ai_addr));
+		"%d: UDP socket listening on %s@%s,%d\n",
+		sd, addr_str,
+		join_iface ? join_iface : "any",
+		nepim_sock_get_port(ai->ai_addr));
 
     nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, sd);
   }
@@ -1210,7 +1219,8 @@ static int udp_listener(const char *ssm_source,
 int nepim_udp_listener(const char *ssm_source,
 		       const char *hostname,
 		       const char *portname, 
-		       int mcast_join)
+		       int mcast_join,
+		       const char *join_iface)
 {
   struct addrinfo hints;
   struct addrinfo *ai_res;
@@ -1224,7 +1234,8 @@ int nepim_udp_listener(const char *ssm_source,
 			-1 /* ssm_source_addrlen */,
 			hostname,
 			portname,
-			mcast_join);
+			mcast_join,
+			join_iface);
 
   memset(&hints, 0, sizeof(hints));
 
@@ -1259,7 +1270,8 @@ int nepim_udp_listener(const char *ssm_source,
 				  ai->ai_addrlen,
 				  hostname,
 				  portname,
-				  mcast_join);
+				  mcast_join,
+				  join_iface);
   }
 
   freeaddrinfo(ai_res);
@@ -1300,7 +1312,7 @@ int nepim_unix_dgram_listener(const char *path)
 			   0 /* tcp nodelay */,
 			   nepim_global.tos,
 			   nepim_global.server_tcp_mss,
-			   -1 /* ssm iface index */,
+			   0  /* join iface */,
 			   0  /* ssm_source_addr */,
 			   -1 /* ssm_source_addrlen */);
   if (sd < 0) {
